
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/inbound/purchaseOrder.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "入库单",
      name: "purchaseOrder",
      url: "/PurchaseOrder/",
      sortName: "id",
    });
    const editFormFields = ref({
      // orderType: "",
      // inboundOrderNo: "",
      // upperOrderNo: "",
      // remark: "",
    });
    const editFormOptions = ref([
      // [
      //   {
      //     title: "单据类型",
      //     required: true,
      //     field: "orderType",
      //     type: "select",
      //     dataKey: "inOrderType",
      //     data: [],
      //   },
      //   {
      //     field: "inboundOrderNo",
      //     title: "单据编号",
      //     type: "string",
      //   },
      //   {
      //     title: "上游单据编号",
      //     field: "upperOrderNo",
      //     type: "string",
      //   },
      //   {
      //     title: "备注",
      //     field: "remark",
      //     type: "textarea",
      //   },
      // ],
    ]);
    const searchFormFields = ref({
      inboundOrderNo: "",
      upperOrderNo: "",
      orderType: "",
      orderStatus: "",
      createType: "",
      creater: "",
      createDate: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "inboundOrderNo", type: "like" },
        { title: "上游单据编号", field: "upperOrderNo", type: "like" },
        {
          title: "单据类型",
          field: "orderType",
          type: "select",
          dataKey: "purchaseType",
          data: [],
        },
        {
          title: "单据状态",
          field: "orderStatus",
          type: "select",
          dataKey: "inboundState",
          data: [],
        },
      ],
      [
        {
          title: "创建方式",
          field: "createType",
          type: "select",
          dataKey: "createType",
          data: [],
        },
        { title: "创建者", field: "creater", type: "like" },
        { title: "创建时间", field: "createDate", type: "datetime" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "purchaseOrderNo",
        title: "采购单号",
        type: "string",
        width: 120,
        align: "left",
        link: true,
      },
      {
        field: "purchaseOrderType",
        title: "单据类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "purchaseType", data: [] },
      },
      {
        field: "supplierCode",
        title: "供应商编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "orderQuantity",
        title: "采购数量",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "purchaseOrderStatus",
        title: "采购单状态",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "orderDate",
        title: "下单日期",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "入库单明细",
      table: "InboundOrderDetail",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left",
        },
        {
          field: "purchaseOrderId",
          title: "采购单主键",
          type: "string",
          width: 90,
          align: "left",
          hidden: true,
        },
        {
          field: "rowNo",
          title: "行号",
          type: "string",
          width: 150,
          align: "left",
        },
        {
          field: "materielCode",
          title: "物料编号",
          type: "select",
          width: 150,
          align: "left",
          edit: { type: "" },
          required: true,
        },
        {
          field: "materielName",
          title: "物料名称",
          type: "string",
          width: 150,
          align: "left",
          edit: { type: "" },
        },
        // {
        //   field: "batchNo",
        //   title: "批次号",
        //   type: "decimal",
        //   width: 90,
        //   align: "left",
        //   edit: { type: "" },
        //   required: true,
        // },
        {
          field: "purchaseDetailQuantity",
          title: "单据数量",
          type: "decimal",
          width: 90,
          align: "left",
        },
        {
          field: "unit",
          title: "单位",
          type: "string",
          width: 120,
          align: "left",
        },
        {
          field: "warehouseId",
          title: "仓库编号",
          type: "string",
          width: 200,
          align: "left",
        },
        {
          field: "purchaseDetailStatus",
          title: "订单明细状态",
          type: "string",
          width: 180,
          align: "left",
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "remark",
          title: "备注",
          type: "string",
          width: 100,
          align: "left",
        },
      ],
      sortName: "id",
      key: "id",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    